/*! For license information please see 445.4606975cacd91d110826.js.LICENSE.txt */
(self.webpackChunk_deathbeds_wxyz_html=self.webpackChunk_deathbeds_wxyz_html||[]).push([[445],{445:e=>{!function(){"use strict";var n="undefined"!=typeof window&&void 0!==window.document?window.document:{},r=e.exports,l=function(){for(var e,r=[["requestFullscreen","exitFullscreen","fullscreenElement","fullscreenEnabled","fullscreenchange","fullscreenerror"],["webkitRequestFullscreen","webkitExitFullscreen","webkitFullscreenElement","webkitFullscreenEnabled","webkitfullscreenchange","webkitfullscreenerror"],["webkitRequestFullScreen","webkitCancelFullScreen","webkitCurrentFullScreenElement","webkitCancelFullScreen","webkitfullscreenchange","webkitfullscreenerror"],["mozRequestFullScreen","mozCancelFullScreen","mozFullScreenElement","mozFullScreenEnabled","mozfullscreenchange","mozfullscreenerror"],["msRequestFullscreen","msExitFullscreen","msFullscreenElement","msFullscreenEnabled","MSFullscreenChange","MSFullscreenError"]],l=0,t=r.length,c={};l<t;l++)if((e=r[l])&&e[1]in n){for(l=0;l<e.length;l++)c[r[0][l]]=e[l];return c}return!1}(),t={change:l.fullscreenchange,error:l.fullscreenerror},c={request:function(e,r){return new Promise(function(t,c){var s=function(){this.off("change",s),t()}.bind(this);this.on("change",s);var u=(e=e||n.documentElement)[l.requestFullscreen](r);u instanceof Promise&&u.then(s).catch(c)}.bind(this))},exit:function(){return new Promise(function(e,r){if(this.isFullscreen){var t=function(){this.off("change",t),e()}.bind(this);this.on("change",t);var c=n[l.exitFullscreen]();c instanceof Promise&&c.then(t).catch(r)}else e()}.bind(this))},toggle:function(e,n){return this.isFullscreen?this.exit():this.request(e,n)},onchange:function(e){this.on("change",e)},onerror:function(e){this.on("error",e)},on:function(e,r){var l=t[e];l&&n.addEventListener(l,r,!1)},off:function(e,r){var l=t[e];l&&n.removeEventListener(l,r,!1)},raw:l};l?(Object.defineProperties(c,{isFullscreen:{get:function(){return Boolean(n[l.fullscreenElement])}},element:{enumerable:!0,get:function(){return n[l.fullscreenElement]}},isEnabled:{enumerable:!0,get:function(){return Boolean(n[l.fullscreenEnabled])}}}),r?e.exports=c:window.screenfull=c):r?e.exports={isEnabled:!1}:window.screenfull={isEnabled:!1}}()}}]);